@@ -17,17 +17,17 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with GNU Emacs; see the file COPYING.  If not, write to
+# along with DameBasics; see the file COPYING.  If not, write to
 # the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301 USA,
 
 class Hanoi(object):
 
-  def hanoi(self, discos):
-    if (discos == 1):
-        return 1
+    def hanoi(self, discos):
+        if (discos == 1):
+            return 1
     else:
         return 1 + (2 * (self.hanoi(discos - 1)))
 
-h = Hanoi()
-print(h.hanoi(4))
+# h = Hanoi()
+# print(h.hanoi(4))
